@@ -6,13 +6,14 @@ use 5.016;
 use exact;
 use exact::class;
 use Mojo::DOM;
-use Mojo::File;
+use Mojo::Util qw( encode decode );
+use Mojo::File 'path';
 use Mojo::URL;
 use Mojo::UserAgent;
 use Bible::OBML 1.14;
 use Bible::Reference 1.04;
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 has ua  => sub { return Mojo::UserAgent->new };
 has url => sub { return Mojo::URL->new('https://www.biblegateway.com/passage/') };
@@ -194,14 +195,14 @@ sub save {
     my ( $self, $filename ) = @_;
     croak('No filename provided to save to') unless ($filename);
     croak('No result to return HTML for') unless ( $self->_body );
-    Mojo::File->new($filename)->spurt( $self->_body );
+    path($filename)->spurt( $self->_body );
     return $self;
 }
 
 sub load {
     my ( $self, $filename ) = @_;
     croak('No filename provided to save to') unless ($filename);
-    $self->_parse( Mojo::File->new($filename)->slurp );
+    $self->_parse( decode( 'UTF-8', path($filename)->slurp ) );
     return $self;
 }
 
@@ -219,7 +220,7 @@ Bible::OBML::Gateway - Bible Gateway content conversion to Open Bible Markup Lan
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML-Gateway.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML-Gateway)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML-Gateway/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML-Gateway)
